"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var filterRowByEquation = function (filterNode, row, getData) {
    if (filterNode.type === 'equation') {
        if (getData) {
            row = getData(row);
        }
        switch (filterNode.op) {
            case '===': {
                // @ts-ignore
                return row[filterNode.key] === filterNode.value;
            }
            case '!==': {
                // @ts-ignore
                return row[filterNode.key] !== filterNode.value;
            }
            case '<': {
                // @ts-ignore
                return row[filterNode.key] < filterNode.value;
            }
            case '>': {
                // @ts-ignore
                return row[filterNode.key] > filterNode.value;
            }
            case '<=': {
                // @ts-ignore
                return row[filterNode.key] <= filterNode.value;
            }
            case '>=': {
                // @ts-ignore
                return row[filterNode.key] >= filterNode.value;
            }
            case 'contains': {
                // @ts-ignore
                return row[filterNode.key].includes(filterNode.value);
            }
            case '!contains': {
                // @ts-ignore
                return !row[filterNode.key].includes(filterNode.value);
            }
        }
    }
    else if (filterNode.type === 'and') {
        for (var _i = 0, _a = Object.values(filterNode.equations); _i < _a.length; _i++) {
            var equation = _a[_i];
            if (!filterRowByEquation(equation, row, getData)) {
                return false;
            }
        }
        return true;
    }
    else if (filterNode.type === 'or') {
        for (var _b = 0, _c = Object.values(filterNode.equations); _b < _c.length; _b++) {
            var equation = _c[_b];
            if (filterRowByEquation(equation, row, getData)) {
                return true;
            }
        }
        return false;
    }
    throw new Error('Unsupported equation type given: ' + filterNode);
};
var buildFilterTree = function (filter) {
    return utils_1.buildTree(filter.equations, filter.root);
};
exports.buildFilterTree = buildFilterTree;
var filter = function (data, filter, getData) {
    if (getData === void 0) { getData = null; }
    var filterTree = buildFilterTree(filter);
    var filterFunction = function (row) { return filterRowByEquation(filterTree, row, getData); };
    return data.filter(filterFunction);
};
exports.filter = filter;
exports.default = filter;
//# sourceMappingURL=filtry.js.map